@@ -191,13 +191,14 @@ void InterfaceStatistics::genNewHour( const QDateTime &dateTime )
         return;
 
     int ruleIndex = ruleForDate( dateTime.date() );
+
+    hours->createEntry( dateTime );
+
     if ( ruleIndex >= 0  && isOffpeak( mStatsRules[ruleIndex], dateTime ) )
     {
         hours->addTrafficType( KNemoStats::OffpeakTraffic );
     }
 
-    hours->createEntry( dateTime );
-
     resetWarnings( hours->periodType() );
 }
 
@@ -978,6 +979,16 @@ void InterfaceStatistics::checkValidEntry()
             hours->updateDateText( i );
     }
 
+    foreach ( StatisticsModel * s, mModels )
+    {
+        if ( s->periodType() == KNemoStats::HourArchive || s->periodType() == KNemoStats::Hour )
+            continue;
+        foreach ( KNemoStats::TrafficType t, hours->trafficTypes() )
+        {
+            s->addTrafficType( t );
+        }
+    }
+
     QDateTime ndt = curDateTime.addSecs( 3600 - curDateTime.time().minute()*60 - curDateTime.time().second() );
 
     int secs = curDateTime.secsTo( ndt );
